

## 天志互联，厘米星球平台

### 1.0.2.11 更新内容
* 获取用户积分接口

### 1.0.2.10 更新内容
* 变更用户积分接口日志调整

### 1.0.2.9 更新内容
* 新增变更用户积分接口

### 1.0.2.8 更新内容
* 新增百度AI内容审核接口

### 1.0.2.7 更新内容
* iOS和Android设备不能同时登录

### 1.0.2.6 更新内容
* 字典表，搜索关键词统计

### 1.0.2.5 更新内容
* 未登录时token处理修改

### 1.0.2.4 更新内容
* 未登录时获取token信息bug修改

### 1.0.2.3 更新内容
* 缓存bug修改
* 手机验证码修改

### 1.0.2.2 更新内容
* 数据统计相关
* 统计用户停留时间
* 通知小红点数量

### 1.0.2.1 更新内容
* 获取关注的用户平台ID列表

### 1.0.2 更新内容
* 用户关注相关

### 1.0.1 更新内容
* 初始版本